# core.spectrogram

## AudioSpectrogram

::: fastaudio.core.spectrogram.AudioSpectrogram
    :docstring:
    :members: create duration height width show


## AudioToSpec

::: fastaudio.core.spectrogram.AudioToSpec
    :docstring:
    :members: from_cfg

## SpectrogramTransformer

::: fastaudio.core.spectrogram.SpectrogramTransformer
    :docstring:

## AudioToMFCC

::: fastaudio.core.spectrogram.AudioToMFCC
    :docstring:
    :members: from_cfg
